@@ -115,18 +115,17 @@ void on_about()
 	char * authors[]={"Jean Bréfort",NULL};
 	char * documentors[] = {NULL};
 	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/pixmaps/gnome-crystal-logo.png", NULL);
-	char * translators = g_strconcat (
-			_("Jean Bréfort: French"), "\n",
-			_("Tigrux: Spanish"),"\n",
-			_("Costantino Ceoldo: Italian"), "\n",
-			_("Nikodem Kuznik: Polish"), NULL);
+	char *translator_credits = _("translator_credits");
 	GtkWidget* about = gnome_about_new(_("Gnome Crystal"), VERSION,
 										_("(C) 1999-2004 by Jean Bréfort"),
 										_("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
-										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
+										(const gchar**) authors, (const gchar**) documentors,
+										(strcmp (translator_credits, "translator_credits") != 0 ? 
+											(const char *)translator_credits : NULL),
+										pixbuf);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
-	g_free (translators);
+	SET_ICON(about);
 	gtk_widget_show_all(about);
 }
 
@@ -229,8 +228,9 @@ static bool do_load(const gchar* filename, gcView* pView)
 		if (!pDoc->IsDirty()) return true;
 		else
 		{
-			gchar* str = g_strdup_printf(_("``%s'' has been modified since last saving. Do you wish to come back to saved version?"), pDoc->GetTitle());
+			gchar* str = g_strdup_printf(_("\"%s\" has been modified since last saving. Do you wish to come back to saved version?"), pDoc->GetTitle());
 			GtkWidget* mbox = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+			SET_ICON(mbox);
 			int res = gtk_dialog_run(GTK_DIALOG(mbox));
 			if (res != GTK_RESPONSE_YES) return true;
 		}
@@ -388,6 +388,7 @@ static GnomeUIInfo tool_bar [] = {
 gcApplication::gcApplication()
 {
 	m_App = gnome_app_new(_("Gnome Crystal"), _("Gnome Crystal"));
+	SET_ICON(m_App);
 	gnome_app_create_menus_with_data((GnomeApp*)m_App, main_menu, this);
 	gnome_app_create_toolbar_with_data((GnomeApp*)m_App, tool_bar, this);
 	m_WindowsMenu = GTK_MENU(windows_menu[0].widget->parent);
@@ -517,6 +518,7 @@ void gcApplication::OnFilePrint()
 	int do_preview, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
 	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)"Print test", GNOME_PRINT_DIALOG_COPIES));
+	SET_ICON (gpd);
 	gnome_print_dialog_set_copies(gpd, copies, collate);
 	switch (gtk_dialog_run(GTK_DIALOG(gpd)))
 	{
@@ -541,7 +543,9 @@ void gcApplication::OnFilePrint()
 	gnome_print_job_close(gpj);
 	if (do_preview)
 	{
-		gtk_widget_show (gnome_print_job_preview_new (gpj, (const guchar*)_("Preview")));
+		GtkWidget *preview = gnome_print_job_preview_new (gpj, (const guchar*)_("Preview"));
+		SET_ICON (preview);
+		gtk_widget_show (preview);
 	}
 	else
 	{
