@@ -4,7 +4,7 @@
  * Gnome Crystal
  * gcrystal-bonobo.h 
  *
- * Copyright (C) 2001-2002
+ * Copyright (C) 2001-2003
  *
  * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
  *
@@ -28,22 +28,8 @@
 #define GCRYSTAL_BONOBO_H
 
 #include "document.h"
-#include <bonobo.h>
+#include <libbonobo.h>
+#include <libbonoboui.h>
 
-typedef struct
-{
-	BonoboEmbeddable *embeddable;
-	gcDocument *pDoc;
-	
-} embeddable_data_t;
-
-typedef struct
-{
-	BonoboView *view;
-	embeddable_data_t *data;
-	GtkWidget *widget;
-	gcView *pView;
-} view_data_t;
-
-BonoboObject * embeddable_factory(BonoboGenericFactory * fact, void* data);
+BonoboObject * gcrystal_factory(BonoboGenericFactory * fact, const char *component_id, void* data);
 #endif//GCRYSTAL_BONOBO
