@@ -4,9 +4,9 @@
  * Gnome Crystal
  * linesdlg.cc 
  *
- * Copyright (C) 2002-2003
+ * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -90,7 +90,7 @@ static void on_medians_toggled(GtkToggleButton* btn, gcLinesDlg *pBox)
 	pBox->OnToggledSpecial(medians);
 }
 
-gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines.glade", "lines", "lines_dalog")
+gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines.glade", "lines")
 {
 	m_pDoc = pDoc;
 	pDoc->NotifyDialog(this);
@@ -113,7 +113,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_X1);
-	column = gtk_tree_view_column_new_with_attributes("x1", renderer, "text", COLUMN_X1, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("x1"), renderer, "text", COLUMN_X1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -123,7 +123,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Y1);
-	column = gtk_tree_view_column_new_with_attributes("y1", renderer, "text", COLUMN_Y1, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("y1"), renderer, "text", COLUMN_Y1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -133,7 +133,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Z1);
-	column = gtk_tree_view_column_new_with_attributes("z1", renderer, "text", COLUMN_Z1, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("z1"), renderer, "text", COLUMN_Z1, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -143,7 +143,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_X2);
-	column = gtk_tree_view_column_new_with_attributes("x2", renderer, "text", COLUMN_X2, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("x2"), renderer, "text", COLUMN_X2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -153,7 +153,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Y2);
-	column = gtk_tree_view_column_new_with_attributes("y2", renderer, "text", COLUMN_Y2, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("y2"), renderer, "text", COLUMN_Y2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -163,7 +163,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK(on_edited), this);
 	g_object_set(G_OBJECT(renderer), "editable", true, NULL);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_Z2);
-	column = gtk_tree_view_column_new_with_attributes("z2", renderer, "text", COLUMN_Z2, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("z2"), renderer, "text", COLUMN_Z2, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN (column), 50);
@@ -172,7 +172,7 @@ gcLinesDlg::gcLinesDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/lines
 	renderer = gtk_cell_renderer_toggle_new();
 	g_signal_connect (G_OBJECT (renderer), "toggled", G_CALLBACK(on_toggled), this);
 	g_object_set_data(G_OBJECT (renderer), "column", (gint *)COLUMN_SINGLE);
-	column = gtk_tree_view_column_new_with_attributes("single", renderer, "active", COLUMN_SINGLE, NULL);
+	column = gtk_tree_view_column_new_with_attributes(_("Single"), renderer, "active", COLUMN_SINGLE, NULL);
 	/* set this column to a fixed sizing (of 50 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN(column), 50);
@@ -420,7 +420,7 @@ void gcLinesDlg::OnEdited(GtkCellRendererText *cell, const gchar *path_string, c
 
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(LineList), &iter, path);
 
-	gint i = gtk_tree_path_get_indices (path)[0], j  = (int)g_object_get_data(G_OBJECT (cell), "column");
+	gint i = gtk_tree_path_get_indices (path)[0], j  = (long)g_object_get_data(G_OBJECT (cell), "column");
 	double x = atof(new_text);
 	gtk_list_store_set(LineList, &iter, j, x, -1);
 	switch (j)
